@@ -17,14 +17,14 @@ class Scraper:
     """
     def __init__(self, resonpse) -> None:
         self.response = resonpse
-        self.title = self.getTitle()
         self.topic = List(Topic)
         self.date = None
         self.url = resonpse.url
         self.origin = self.response.origin
         self._soup = BeautifulSoup(self.resonpse.text, BS4_SETTING)
+        self.title = self.getTitle()
 
-    def getTitle(self):
+    def getTitle(self) -> str:
         """
         Get The title of a webpage
         """
